@@ -426,7 +426,7 @@ camel_scalix_folder_new (CamelStore * store,
     scalix_folder->cachedir =
         scalix_store_build_filename (store, folder->full_name);
     
-    e_util_mkdir_hier (scalix_folder->cachedir, 0777);
+    g_mkdir_with_parents (scalix_folder->cachedir, 0777);
 
     scalix_folder->cache =
         camel_data_cache_new (scalix_folder->cachedir, 0, NULL);
@@ -1864,7 +1864,7 @@ scalix_rename (CamelFolder * folder, const char *new)
     cachedir = scalix_store_build_filename (store, folder->full_name);
     g_free (scalix_folder->cachedir);
     scalix_folder->cachedir = cachedir;
-    e_util_mkdir_hier (scalix_folder->cachedir, 0777);
+    g_mkdir_with_parents (scalix_folder->cachedir, 0777);
 
     scalix_folder->cache = camel_data_cache_new (scalix_folder->cachedir,
                                                  0, NULL);
