@@ -382,7 +382,7 @@ camel_scalix_utils_set_unexpected_token_error (CamelException *ex, CamelSCALIXEn
 		g_string_append (errmsg, token->v.qstring);
 		break;
 	case CAMEL_SCALIX_TOKEN_LITERAL:
-		g_string_append_printf (errmsg, "{%u}", token->v.literal);
+		g_string_append_printf (errmsg, "{%zu}", token->v.literal);
 		break;
 	case CAMEL_SCALIX_TOKEN_NUMBER:
 		g_string_append_printf (errmsg, "%u", token->v.number);
