@@ -637,7 +637,7 @@ scalix_container_constructor (GType type,
     }
 
     /* Create the local attachment store direcotry */
-    e_util_mkdir_hier (priv->local_attachment_store, 0700);
+    g_mkdir_with_parents (priv->local_attachment_store, 0700);
 
     /* Get the camel store */
     camel_exception_init (&ex);
